Datastore Libraries
===================

.. _algoliasearch:

Algoliasearch
-------------

.. automodule:: ddtrace.contrib.algoliasearch


.. _cassandra:

Cassandra
---------

.. automodule:: ddtrace.contrib.cassandra


.. _consul:

Consul
------

.. automodule:: ddtrace.contrib.consul


.. _dogpile.cache:

dogpile.cache
-------------

.. automodule:: ddtrace.contrib.dogpile_cache


.. _elasticsearch:

Elasticsearch
-------------

.. automodule:: ddtrace.contrib.elasticsearch


.. _flask_cache:

Flask Cache
-----------

.. automodule:: ddtrace.contrib.flask_cache


.. _mongodb:

MongoDB
-------

.. _mongoengine:

Mongoengine
^^^^^^^^^^^

.. automodule:: ddtrace.contrib.mongoengine


.. _pymongo:

Pymongo
^^^^^^^

.. automodule:: ddtrace.contrib.pymongo


Memcached
---------

.. _pylibmc:

pylibmc
^^^^^^^

.. automodule:: ddtrace.contrib.pylibmc

.. _pymemcache:

pymemcache
^^^^^^^^^^

.. automodule:: ddtrace.contrib.pymemcache

MySQL
-----

.. _mysql-connector:

mysql-connector
^^^^^^^^^^^^^^^

.. automodule:: ddtrace.contrib.mysql


.. _mysqlclient:
.. _MySQL-python:
.. _mysqldb:

mysqlclient/MySQL-python
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: ddtrace.contrib.mysqldb

.. _pymysql:

pymysql
^^^^^^^

.. automodule:: ddtrace.contrib.pymysql


Postgres
--------

.. _aiopg:

aiopg
^^^^^

.. automodule:: ddtrace.contrib.aiopg


.. _psycopg2:

psycopg
^^^^^^^

.. automodule:: ddtrace.contrib.psycopg



Redis
-----

.. _redis:

redis
^^^^^

.. automodule:: ddtrace.contrib.redis


.. _rediscluster:

redis-py-cluster
^^^^^^^^^^^^^^^^

.. automodule:: ddtrace.contrib.rediscluster


.. _sqlalchemy:

SQLAlchemy
----------

.. automodule:: ddtrace.contrib.sqlalchemy


.. _sqllite:

SQLite
------

.. automodule:: ddtrace.contrib.sqlite3

.. _vertica:

Vertica
-------

.. automodule:: ddtrace.contrib.vertica
